@@ -36,7 +36,6 @@
 #include "workbook-control.h"
 #include "wbc-gtk.h"
 #include "number-match.h"
-#include "widgets/widget-font-selector.h"
 #include "widgets/gnumeric-cell-renderer-text.h"
 
 #include "gnumeric-conf.h"
@@ -595,36 +594,64 @@ wordlist_pref_create_widget (GOConfNode *node, GtkWidget *grid,
 /*                     Default Font Selector                                               */
 /*******************************************************************************************/
 
+static void
+do_set_font (GOFontSel *fs,
+	     const char *name, double size,
+	     gboolean is_bold, gboolean is_italic)
+{
+	PangoFontDescription *desc;
+
+	desc = pango_font_description_new ();
+	pango_font_description_set_family (desc, name);
+	pango_font_description_set_size (desc, PANGO_SCALE * size);
+	pango_font_description_set_weight
+		(desc,
+		 is_bold ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL);
+	pango_font_description_set_style
+		(desc,
+		 is_italic ? PANGO_STYLE_ITALIC : PANGO_STYLE_NORMAL);
+
+	go_font_sel_set_font_desc (fs, desc);
+	pango_font_description_free (desc);
+}
+
+
 static void
 cb_pref_font_set_fonts (G_GNUC_UNUSED GOConfNode *node,
 			G_GNUC_UNUSED char const *key,
 			GtkWidget *page)
 {
-	FontSelector *fs = FONT_SELECTOR (page);
+	GOFontSel *fs = GO_FONT_SEL (page);
 
-	font_selector_set_name (fs, gnm_conf_get_core_defaultfont_name ());
-	font_selector_set_points (fs, gnm_conf_get_core_defaultfont_size ());
-	font_selector_set_style (fs,
-				 gnm_conf_get_core_defaultfont_bold (),
-				 gnm_conf_get_core_defaultfont_italic ());
+	do_set_font (fs,
+		     gnm_conf_get_core_defaultfont_name (),
+		     gnm_conf_get_core_defaultfont_size (),
+		     gnm_conf_get_core_defaultfont_bold (),
+		     gnm_conf_get_core_defaultfont_italic ());
 }
 
 static gboolean
-cb_pref_font_has_changed (G_GNUC_UNUSED FontSelector *fs,
-			  GnmStyle *mstyle, PrefState *state)
+cb_pref_font_has_changed (GOFontSel *fs, G_GNUC_UNUSED PangoAttrList *attrs,
+			  PrefState *state)
 {
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_SIZE))
-		gnm_conf_set_core_defaultfont_size
-			(gnm_style_get_font_size (mstyle));
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_NAME))
+	PangoFontDescription *desc = go_font_sel_get_font_desc (fs);
+	PangoFontMask fields = pango_font_description_get_set_fields (desc);
+
+	if (fields & PANGO_FONT_MASK_FAMILY)
 		gnm_conf_set_core_defaultfont_name
-			(gnm_style_get_font_name (mstyle));
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_BOLD))
+			(pango_font_description_get_family (desc));
+	if (fields & PANGO_FONT_MASK_SIZE)
+		gnm_conf_set_core_defaultfont_size
+			(pango_font_description_get_size (desc) / (double)PANGO_SCALE);
+	if (fields & PANGO_FONT_MASK_WEIGHT)
 		gnm_conf_set_core_defaultfont_bold
-			(gnm_style_get_font_bold (mstyle));
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_ITALIC))
+			(pango_font_description_get_weight (desc) >= PANGO_WEIGHT_BOLD);
+	if (fields & PANGO_FONT_MASK_STYLE)
 		gnm_conf_set_core_defaultfont_italic
-			(gnm_style_get_font_italic (mstyle));
+			(pango_font_description_get_style (desc) != PANGO_STYLE_NORMAL);
+
+	pango_font_description_free (desc);
+
 	return TRUE;
 }
 
@@ -634,7 +661,9 @@ pref_font_initializer (PrefState *state,
 		       G_GNUC_UNUSED GtkNotebook *notebook,
 		       G_GNUC_UNUSED gint page_num)
 {
-	GtkWidget *page = font_selector_new ();
+	GtkWidget *page = g_object_new (GO_TYPE_FONT_SEL,
+					"show-style", TRUE,
+					NULL);
 
 	cb_pref_font_set_fonts (NULL, NULL, page);
 
@@ -659,31 +688,35 @@ cb_pref_font_hf_set_fonts (G_GNUC_UNUSED GOConfNode *node,
 			   G_GNUC_UNUSED char const *key,
 			   GtkWidget *page)
 {
-	FontSelector *fs = FONT_SELECTOR (page);
-
-	font_selector_set_name (fs, gnm_conf_get_printsetup_hf_font_name ());
-	font_selector_set_points (fs, gnm_conf_get_printsetup_hf_font_size ());
-	font_selector_set_style (fs,
-				 gnm_conf_get_printsetup_hf_font_bold (),
-				 gnm_conf_get_printsetup_hf_font_italic ());
+	GOFontSel *fs = GO_FONT_SEL (page);
+	do_set_font (fs,
+		     gnm_conf_get_printsetup_hf_font_name (),
+		     gnm_conf_get_printsetup_hf_font_size (),
+		     gnm_conf_get_printsetup_hf_font_bold (),
+		     gnm_conf_get_printsetup_hf_font_italic ());
 }
 
 static gboolean
-cb_pref_font_hf_has_changed (G_GNUC_UNUSED FontSelector *fs,
-			     GnmStyle *mstyle, PrefState *state)
+cb_pref_font_hf_has_changed (GOFontSel *fs, G_GNUC_UNUSED PangoAttrList *attrs,
+			     PrefState *state)
 {
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_SIZE))
-		gnm_conf_set_printsetup_hf_font_size
-			(gnm_style_get_font_size (mstyle));
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_NAME))
+	PangoFontDescription *desc = go_font_sel_get_font_desc (fs);
+	PangoFontMask fields = pango_font_description_get_set_fields (desc);
+
+	if (fields & PANGO_FONT_MASK_FAMILY)
 		gnm_conf_set_printsetup_hf_font_name
-			(gnm_style_get_font_name (mstyle));
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_BOLD))
+			(pango_font_description_get_family (desc));
+	if (fields & PANGO_FONT_MASK_SIZE)
+		gnm_conf_set_printsetup_hf_font_size
+			(pango_font_description_get_size (desc) / (double)PANGO_SCALE);
+	if (fields & PANGO_FONT_MASK_WEIGHT)
 		gnm_conf_set_printsetup_hf_font_bold
-			(gnm_style_get_font_bold (mstyle));
-	if (gnm_style_is_element_set (mstyle, MSTYLE_FONT_ITALIC))
+			(pango_font_description_get_weight (desc) >= PANGO_WEIGHT_BOLD);
+	if (fields & PANGO_FONT_MASK_STYLE)
 		gnm_conf_set_printsetup_hf_font_italic
-			(gnm_style_get_font_italic (mstyle));
+			(pango_font_description_get_style (desc) != PANGO_STYLE_NORMAL);
+
+	pango_font_description_free (desc);
 
 	return TRUE;
 }
@@ -694,7 +727,9 @@ pref_font_hf_initializer (PrefState *state,
 			  G_GNUC_UNUSED GtkNotebook *notebook,
 			  G_GNUC_UNUSED gint page_num)
 {
-	GtkWidget *page = font_selector_new ();
+	GtkWidget *page = g_object_new (GO_TYPE_FONT_SEL,
+					"show-style", TRUE,
+					NULL);
 
 	cb_pref_font_hf_set_fonts (NULL, NULL, page);
 	connect_notification (gnm_conf_get_printsetup_dir_node (),
@@ -842,11 +877,6 @@ pref_window_page_initializer (PrefState *state,
 				    _("Default Number of Columns in a Sheet"));
 	power_of_2_handlers (w);
 
-	bool_pref_create_widget (gnm_conf_get_core_gui_editing_livescrolling_node (),
-                                 page, row++,
-				 gnm_conf_set_core_gui_editing_livescrolling,
-				 gnm_conf_get_core_gui_editing_livescrolling,
-				 _("Live Scrolling"));
 	bool_pref_create_widget (gnm_conf_get_core_gui_cells_function_markers_node (),
 				 page, row++,
 				 gnm_conf_set_core_gui_cells_function_markers,
