@@ -219,7 +219,7 @@ dump_externals (GPtrArray *defs, FILE *out)
  * A generic utility routine to operate on all funtion defs
  * in various ways.  @dump_type will change/extend as needed
  * Right now
- * 0 :
+ * 0 : www.gnumeric.org's function.shtml page
  * 1 :
  * 2 : generate_po
  * 3 : dump function usage count
@@ -229,7 +229,7 @@ void
 function_dump_defs (char const *filename, int dump_type)
 {
 	FILE *output_file;
-	char *up;
+	char *up, *catname;
 	unsigned i;
 	GPtrArray *ordered;
 	GnmFuncGroup const *group = NULL;
@@ -483,11 +483,15 @@ function_dump_defs (char const *filename, int dump_type)
 					 group->display_name->str);
 			}
 			up = g_ascii_strup (fd->name, -1);
+			catname = g_strdup (group->display_name->str);
+			while (strchr (catname, ' '))
+				*strchr (catname, ' ') = '_';
 			fprintf (output_file, "<tr class=\"function\">\n");
 			fprintf (output_file,
-				 "<td><a href =\"doc/gnumeric-function-%s.shtml\">%s</a></td>\n",
-				 up, fd->name);
+				 "<td><a href =\"https://help.gnome.org/users/gnumeric/stable/CATEGORY_%s.html.en#gnumeric-function-%s\">%s</a></td>\n",
+				 catname, up, fd->name);
 			g_free (up);
+			g_free (catname);
 			fprintf (output_file,
 				 "<td class=\"%s\"><a href=\"mailto:gnumeric-list@gnome.org?subject=Re: %s implementation\">%s</a></td>\n",
 				 implementation[fd->impl_status].klass,
