@@ -2,7 +2,7 @@
 #ifndef _GNM_GUI_UTIL_H_
 # define _GNM_GUI_UTIL_H_
 
-#include "gui-gnumeric.h"
+#include "gnumeric-fwd.h"
 #include <goffice/goffice.h>
 #include "numbers.h"
 #include <gtk/gtk.h>
@@ -33,19 +33,16 @@ int gnm_gtk_radio_group_get_selected (GSList *radio_group);
 int gnm_gui_group_value (gpointer gui, char const * const group[]);
 
 /* Use this on menus that are popped up */
-void gnumeric_popup_menu (GtkMenu *menu, GdkEventButton *event);
+void gnumeric_popup_menu (GtkMenu *menu, GdkEvent *event);
 
 /*
- * Pseudo-tool-tip support code.
+ * Pseudo-tooltip support code.
  */
 void        gnumeric_position_tooltip (GtkWidget *tip, int px, int py,
 				       gboolean horizontal);
-GtkWidget  *gnumeric_create_tooltip_widget (void);
-GtkWidget  *gnumeric_create_tooltip_text_view_widget (void);
 GtkWidget  *gnumeric_create_tooltip (GtkWidget *ref_widget);
 GtkWidget  *gnumeric_convert_to_tooltip (GtkWidget *ref_widget,
 					 GtkWidget *widget);
-void        gnumeric_tooltip_set_style (GtkWidget *widget);
 
 GtkBuilder *gnm_gtk_builder_load (char const *uifile, char const *domain,
 				 GOCmdContext *cc);
@@ -69,7 +66,7 @@ void gnumeric_create_popup_menu (GnumericPopupMenuElement const *elements,
 				 gpointer user_data,
 				 int display_filter,
 				 int sensitive_filter,
-				 GdkEventButton *event);
+				 GdkEvent *event);
 
 #define gnumeric_filter_modifiers(a) ((a) &(~(GDK_LOCK_MASK|GDK_MOD2_MASK|GDK_MOD5_MASK)))
 
@@ -110,6 +107,8 @@ void gnm_link_button_and_entry (GtkWidget *button, GtkWidget *entry);
 void gnm_widget_set_cursor_type (GtkWidget *w, GdkCursorType ct);
 void gnm_widget_set_cursor (GtkWidget *w, GdkCursor *ct);
 
+int gnm_widget_measure_string (GtkWidget *w, const char *s);
+
 GtkWidget * gnumeric_message_dialog_create (GtkWindow * parent,
                                             GtkDialogFlags flags,
                                             GtkMessageType type,
