@@ -44,6 +44,7 @@ typedef long double gnm_float;
 #define gnm_atanh atanhl
 #define gnm_ceil ceill
 #define gnm_cosh coshl
+#define gnm_cospi go_cospil
 #define gnm_erf erfl
 #define gnm_erfc erfcl
 #define gnm_exp expl
@@ -75,10 +76,12 @@ typedef long double gnm_float;
 #define gnm_pow2 go_pow2l
 #define gnm_render_general go_render_generall
 #define gnm_sinh sinhl
+#define gnm_sinpi go_sinpil
 #define gnm_sqrt sqrtl
 #define gnm_strto go_strtold
 #define gnm_sub_epsilon go_sub_epsilonl
 #define gnm_tanh tanhl
+#define gnm_tanpi go_tanpil
 #ifndef GNM_REDUCES_TRIG_RANGE
 #define gnm_sin sinl
 #define gnm_cos cosl
@@ -101,24 +104,33 @@ typedef long double gnm_float;
 #define GNM_const(_c)	_c ## L
 
 #define GnmQuad GOQuadl
-#define gnm_quad_start go_quad_startl
-#define gnm_quad_end go_quad_endl
-#define gnm_quad_init go_quad_initl
-#define gnm_quad_value go_quad_valuel
+#define gnm_quad_acos go_quad_acosl
 #define gnm_quad_add go_quad_addl
-#define gnm_quad_sub go_quad_subl
-#define gnm_quad_mul go_quad_mull
+#define gnm_quad_asin go_quad_asinl
+#define gnm_quad_cos go_quad_cosl
+#define gnm_quad_cospi go_quad_cospil
 #define gnm_quad_div go_quad_divl
-#define gnm_quad_mul12 go_quad_mul12l
-#define gnm_quad_sqrt go_quad_sqrtl
-#define gnm_quad_pow go_quad_powl
+#define gnm_quad_e go_quad_el
+#define gnm_quad_end go_quad_endl
 #define gnm_quad_exp go_quad_expl
 #define gnm_quad_expm1 go_quad_expm1l
-#define gnm_quad_zero go_quad_zerol
+#define gnm_quad_init go_quad_initl
+#define gnm_quad_ln2 go_quad_ln2l
+#define gnm_quad_log go_quad_logl
+#define gnm_quad_mul go_quad_mull
+#define gnm_quad_mul12 go_quad_mul12l
 #define gnm_quad_one go_quad_onel
 #define gnm_quad_pi go_quad_pil
-#define gnm_quad_e go_quad_el
+#define gnm_quad_2pi go_quad_2pil
+#define gnm_quad_pow go_quad_powl
+#define gnm_quad_sin go_quad_sinl
+#define gnm_quad_sinpi go_quad_sinpil
+#define gnm_quad_sqrt go_quad_sqrtl
 #define gnm_quad_sqrt2 go_quad_sqrt2l
+#define gnm_quad_start go_quad_startl
+#define gnm_quad_sub go_quad_subl
+#define gnm_quad_value go_quad_valuel
+#define gnm_quad_zero go_quad_zerol
 #define GnmAccumulator GOAccumulatorl
 #define gnm_accumulator_start go_accumulator_startl
 #define gnm_accumulator_end go_accumulator_endl
@@ -143,6 +155,7 @@ typedef double gnm_float;
 #define gnm_atanh atanh
 #define gnm_ceil ceil
 #define gnm_cosh cosh
+#define gnm_cospi go_cospi
 #define gnm_erf erf
 #define gnm_erfc erfc
 #define gnm_exp exp
@@ -174,10 +187,12 @@ typedef double gnm_float;
 #define gnm_pow2 go_pow2
 #define gnm_render_general go_render_general
 #define gnm_sinh sinh
+#define gnm_sinpi go_sinpi
 #define gnm_sqrt sqrt
 #define gnm_strto go_strtod
 #define gnm_sub_epsilon go_sub_epsilon
 #define gnm_tanh tanh
+#define gnm_tanpi go_tanpi
 #ifndef GNM_REDUCES_TRIG_RANGE
 #define gnm_sin sin
 #define gnm_cos cos
@@ -200,24 +215,33 @@ typedef double gnm_float;
 #define GNM_const(_c)	_c
 
 #define GnmQuad GOQuad
-#define gnm_quad_start go_quad_start
-#define gnm_quad_end go_quad_end
-#define gnm_quad_init go_quad_init
-#define gnm_quad_value go_quad_value
+#define gnm_quad_acos go_quad_acos
 #define gnm_quad_add go_quad_add
-#define gnm_quad_sub go_quad_sub
-#define gnm_quad_mul go_quad_mul
+#define gnm_quad_asin go_quad_asin
+#define gnm_quad_cos go_quad_cos
+#define gnm_quad_cospi go_quad_cospi
 #define gnm_quad_div go_quad_div
-#define gnm_quad_mul12 go_quad_mul12
-#define gnm_quad_sqrt go_quad_sqrt
-#define gnm_quad_pow go_quad_pow
+#define gnm_quad_e go_quad_e
+#define gnm_quad_end go_quad_end
 #define gnm_quad_exp go_quad_exp
 #define gnm_quad_expm1 go_quad_expm1
-#define gnm_quad_zero go_quad_zero
+#define gnm_quad_init go_quad_init
+#define gnm_quad_ln2 go_quad_ln2
+#define gnm_quad_log go_quad_log
+#define gnm_quad_mul go_quad_mul
+#define gnm_quad_mul12 go_quad_mul12
 #define gnm_quad_one go_quad_one
 #define gnm_quad_pi go_quad_pi
-#define gnm_quad_e go_quad_e
+#define gnm_quad_2pi go_quad_2pi
+#define gnm_quad_pow go_quad_pow
+#define gnm_quad_sin go_quad_sin
+#define gnm_quad_sinpi go_quad_sinpi
+#define gnm_quad_sqrt go_quad_sqrt
 #define gnm_quad_sqrt2 go_quad_sqrt2
+#define gnm_quad_start go_quad_start
+#define gnm_quad_sub go_quad_sub
+#define gnm_quad_value go_quad_value
+#define gnm_quad_zero go_quad_zero
 #define GnmAccumulator GOAccumulator
 #define gnm_accumulator_start go_accumulator_start
 #define gnm_accumulator_end go_accumulator_end
